@@ -1,6 +1,6 @@
 from enum import Enum
-from spectre.generation import utils
-from spectre.generation import serializer
+from spectre import utils
+from spectre import serializer
 from spectre.model import Entity, SpectreType, Field, UnknownTypeException
 from spectre.config import Config
 
@@ -56,7 +56,7 @@ def get_type(t: SpectreType, name = None):
         return 'int'
     if t is SpectreType.STRING:
         return 'String'
-    if t is SpectreType.DATETIME:
+    if t is SpectreType.TIMESTAMP:
         return 'Instant'
     if t is SpectreType.BOOL:
         return 'boolean'
@@ -116,7 +116,7 @@ def get_class_stub(entity: Entity, imports, config: Config, class_type: ClassTyp
 def get_imports(fields):
     output = set()
     for field in fields:
-        if field.type is SpectreType.DATETIME:
+        if field.type is SpectreType.TIMESTAMP:
             output.add('java.time.Instant')
     return list(output)
 
@@ -232,7 +232,7 @@ def generate_method(method_name, method_map):
             body=method_map.get('body', None),
             annotation=method_map.get('annotation', None)
         )
-    except KeyError as e:
+    except KeyError:
         raise Exception(f'Java generator does not implement method {method_name}')
 
 def generate_repository(entity: Entity, config: Config):
@@ -270,7 +270,7 @@ def generate_repository(entity: Entity, config: Config):
     imports.extend([f'org.springframework.{c}' for c in ['data.jpa.repository.JpaRepository', 'stereotype.Repository']])
     output = get_class_stub(entity, imports, config, ClassType.REPOSITORY)
     for method in config.methods:
-        if method is not 'update':
+        if method in method_map.keys():
             output.extend(generate_method(method, method_map[method]))
     if 'delete' in config.methods:
         output.extend(generate_method('delete_by_id', method_map['delete_by_id']))
@@ -367,8 +367,9 @@ def generate_controller(entity: Entity, config: Config):
     output.extend(create_constructor(ClassType.REST_CONTROLLER.get_name(entity.name), [ (manager_type, manager_var) ] ))
 
     for method in config.methods:
-        output.extend(generate_method(method, method_map[method]))
-        output.append('')
+        if method in method_map.keys():
+            output.extend(generate_method(method, method_map[method]))
+            output.append('')
 
     output.append('}')
     return output
@@ -422,7 +423,7 @@ def generate_manager(entity: Entity, config: Config):
 
     for method in config.methods:
         #update and create is currently the same. dont want to generate twice. If different impl is needed, add update to method map and remove check
-        if method is not 'update':
+        if method in method_map.keys():
             output.extend(generate_method(method, method_map[method]))
             output.append('')
     if 'delete' in config.methods:
@@ -435,6 +436,7 @@ def write_manager(entity: Entity, config: Config):
     return utils.write_to_file('\n'.join(generate_manager(entity, config)), path, config)
 
 def write_dto(entity: Entity, config: Config):
+    #TODO: Add mapping interface between this and model and convenience methods
     path = get_out_path(entity, config, ClassType.DTO)
     return utils.write_to_file('\n'.join(generate_model(entity, config, ClassType.DTO)), path, config)
 
