@@ -1,4 +1,4 @@
-from spectre.generation import utils
+from spectre import utils
 from spectre.config import Config
 from spectre.model import Entity, Field, SpectreType, UnknownTypeException
 
@@ -24,7 +24,7 @@ def convert_type(t: SpectreType, name):
     
     if t is SpectreType.INT: return int_type
     if t is SpectreType.STRING: return string_type
-    if t is SpectreType.DATETIME: return timestamp_type
+    if t is SpectreType.TIMESTAMP: return timestamp_type
     if t is SpectreType.FLOAT: return float_type
     if t is SpectreType.UUID: return id_type
     if t is SpectreType.ENUM: return string_type
